@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 
-package Text::Parser::AutoSplit 0.917;
+package Text::Parser::AutoSplit 0.918;
 
 # ABSTRACT: A role that adds the ability to auto-split a line into fields
 
@@ -10,15 +10,17 @@ our (@EXPORT_OK) = ();
 our (@EXPORT)    = ();
 use Moose::Role;
 use MooseX::CoverableModifiers;
+use String::Util qw(trim);
 
 
 has _fields => (
-    is       => 'rw',
+    is       => 'ro',
     isa      => 'ArrayRef[Str]',
     lazy     => 1,
     init_arg => undef,
     default  => sub { [] },
     traits   => ['Array'],
+    writer   => '_set_fields',
     handles  => {
         'NF'               => 'count',
         'field'            => 'get',
@@ -29,12 +31,17 @@ has _fields => (
     },
 );
 
-requires 'save_record', 'FS';
+requires 'save_record', 'FS', '__read_file_handle';
 
 around save_record => sub {
-    my ( $orig, $self, $line ) = ( shift, shift, shift );
-    $self->_fields( [ split $self->FS, $line ] );
-    $orig->( $self, $line );
+    my ( $orig, $self ) = ( shift, shift );
+    $self->_set_fields( [ split $self->FS, trim( $_[0] ) ] );
+    $orig->( $self, @_ );
+};
+
+after __read_file_handle => sub {
+    my $self = shift;
+    $self->_set_fields( [] );
 };
 
 
@@ -52,7 +59,7 @@ Text::Parser::AutoSplit - A role that adds the ability to auto-split a line into
 
 =head1 VERSION
 
-version 0.917
+version 0.918
 
 =head1 SYNOPSIS
 
@@ -87,11 +94,11 @@ C<Text::Parser::AutoSplit> is a role that gets automatically composed into an ob
 
 =head1 METHODS AVAILABLE ON AUTO-SPLIT
 
-These methods become available when C<auto_split> attribute is true. You'll get a runtime error if you try to use them otherwise. They would be most likely used inside your own implementation of C<L<save_record|Text::Parser/save_record>> since the splits are done for each line.
+These methods become available when C<auto_split> attribute is true. A runtime error will be thrown if they are called without C<auto_split> being set. They can used inside the subclass implementation of C<L<save_record|Text::Parser/save_record>>.
 
 =head2 NF
 
-The name of this method comes from the C<NF> variable in the popular GNU Awk program. It stands for number of fields. Takes no arguments, and returns the number of fields.
+The name of this method comes from the C<NF> variable in the popular L<GNU Awk program|https://www.gnu.org/software/gawk/gawk.html>. Takes no arguments, and returns the number of fields.
 
     sub save_record {
         my $self = shift;
@@ -100,13 +107,19 @@ The name of this method comes from the C<NF> variable in the popular GNU Awk pro
 
 =head2 field
 
-Takes an integer argument and returns the field whose index is passed as argument. You can specify negative elements to start counting from the end. For example index C<-1> is the last element, C<-2> is the penultimate one, etc.
+Takes an integer argument and returns the field whose index is passed as argument.
 
     sub save_record {
         my $self = shift;
         $self->abort if $self->field(0) eq 'END';
     }
 
+You can specify negative elements to start counting from the end. For example index C<-1> is the last element, C<-2> is the penultimate one, etc. Let's say the following is the text on a line in a file:
+
+    THIS           IS          SOME           TEXT
+    field(0)      field(1)    field(2)      field(3)
+    field(-4)    field(-3)   field(-2)     field(-1)
+
 =head2 find_field
 
 This method finds an element matching a given criterion. The match is done by a subroutine reference passed as argument to this method. The subroutine will be called against each field on the line, until one matches or all elements have been checked. Each field will be available in the subroutine as C<$_>. Its behavior is the same as the C<first> function of L<List::Util>.
@@ -161,6 +174,10 @@ L<List::Util>
 
 L<List::SomeUtils>
 
+=item *
+
+L<GNU Awk program|https://www.gnu.org/software/gawk/gawk.html>
+
 =back
 
 =head1 BUGS
